@@ -3,8 +3,8 @@
 pytest_sugar
 ~~~~~~~~~~~~
 
-py.test is a plugin for py.test that changes the default look
-and feel of py.test (e.g. progressbar, show tests that fail instantly).
+pytest-sugar is a plugin for pytest that changes the default look
+and feel of pytest (e.g. progressbar, show tests that fail instantly).
 
 :copyright: see LICENSE for details
 :license: BSD, see LICENSE for more details.
@@ -28,7 +28,7 @@ import pytest
 from _pytest.terminal import TerminalReporter
 
 
-__version__ = '0.9.4'
+__version__ = '0.9.5'
 
 LEN_RIGHT_MARGIN = 0
 LEN_PROGRESS_PERCENTAGE = 5
@@ -165,9 +165,9 @@ def pytest_configure(config):
         except ImportError:
             pass
         else:
-            from distutils.version import LooseVersion
-            xdist_version = LooseVersion(xdist.__version__)
-            if xdist_version >= LooseVersion('1.14'):
+            from packaging import version
+            xdist_version = version.Version(xdist.__version__)
+            if xdist_version >= version.Version('1.14'):
                 config.pluginmanager.register(DeferredXdistPlugin())
 
     if IS_SUGAR_ENABLED and not getattr(config, 'slaveinput', None):
@@ -474,15 +474,16 @@ class SugarTerminalReporter(TerminalReporter):
             if not letter and not word:
                 return
             if self.verbosity > 0:
+                markup = {'red': True}
                 if isinstance(word, tuple):
                     word, markup = word
                 else:
                     if report.passed:
                         markup = {'green': True}
-                    elif report.failed:
-                        markup = {'red': True}
                     elif report.skipped:
                         markup = {'yellow': True}
+                    elif hasattr(report, "rerun") and isinstance(report.rerun, int):
+                        markup = {'blue': True}
                 line = self._locationline(str(report.fspath), *report.location)
                 if hasattr(report, 'node'):
                     self._tw.write("\r\n")
